==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property allow Instructs AWS WAF to allow the web request. See `allow` below for details.
 * @property block Instructs AWS WAF to block the web request. See `block` below for details.
 * @property captcha Instructs AWS WAF to run a Captcha check against the web request. See `captcha` below for details.
 * @property challenge Instructs AWS WAF to run a check against the request to verify that the request is coming from a legitimate client session. See `challenge` below for details.
 * @property count Instructs AWS WAF to count the web request and allow it. See `count` below for details.
 */
public data class WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUse(
    public val allow: WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseAllow? =
        null,
    public val block: WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseBlock? =
        null,
    public val captcha:
    WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseCaptcha? = null,
    public val challenge:
    WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseChallenge? = null,
    public val count: WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseCount? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUse):
            WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUse =
            WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUse(
                allow = javaType.allow().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseAllow.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                block = javaType.block().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseBlock.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                captcha = javaType.captcha().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseCaptcha.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                challenge = javaType.challenge().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseChallenge.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                count = javaType.count().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseCount.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property allow
 * @property block
 * @property captcha Instructs AWS WAF to run a Captcha check against the web request. See `captcha` below for details.
 * @property challenge Instructs AWS WAF to run a check against the request to verify that the request is coming from a legitimate client session. See `challenge` below for details.
 * @property count
 */
public data class WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUse(
    public val allow: WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseAllow? =
        null,
    public val block: WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseBlock? =
        null,
    public val captcha: WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseCaptcha? = null,
    public val challenge: WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseChallenge? = null,
    public val count: WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseCount? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUse): WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUse =
            WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUse(
                allow = javaType.allow().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseAllow.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                block = javaType.block().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseBlock.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                captcha = javaType.captcha().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseCaptcha.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                challenge = javaType.challenge().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseChallenge.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                count = javaType.count().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementManagedRuleGroupStatementRuleActionOverrideActionToUseCount.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
